Plone Intranet Search
=====================

This package aims to provide a common API
for indexing and querying from Plone
to 3rd party search engines e.g. Solr

Features
--------

* Thin API layer to support storage and retrieval of search data

* collective.indexing integration to tie into Plone's catalog operations

* Integration with Plone Intranet UI providing faceting, spell-check, highlighting etc.

Goals
-----

* Initial proof of concept implementing an interface by using the Plone catalog

* Solr backend implementation to be developed during Bristol Plone Intranet sprint 2015

* Possible Elasticsearch or other backend support in the future
